@@ -553,7 +553,11 @@ public:
 	qjackctlAliases *aliases() const;
 
 	// Snap into position helper.
-	QPointF snapPos(qreal x, qreal y) const;
+	QPointF snapPos(const QPointF& pos) const;
+
+	// Search placeholder text accessors.
+	void setSearchPlaceholderText(const QString& text);
+	QString searchPlaceholderText() const;
 
 signals:
 
@@ -654,9 +658,6 @@ protected:
 	const QRectF& boundingRect(bool reset = false);
 	void boundingPos(QPointF& pos);
 
-	// Snap into position helper.
-	void snapPos(QPointF& pos) const;
-
 	// Start search editor...
 	void startSearchEditor(const QString& text = QString());
 
@@ -782,13 +783,19 @@ public:
 	Position position() const;
 
 	// Emit context-menu request.
-	void contextMenu(const QPoint& pos);
+	void requestContextMenu(const QPoint& pos);
+
+	// Request re-positioning.
+	void requestPosition(Position position);
 
 signals:
 
 	// Context-menu request.
 	void contextMenuRequested(const QPoint& pos);
 
+	// Re-positioning request.
+	void positionRequested(int position);
+
 public slots:
 
 	// Update view slot.
